#[repr(C)]
pub struct QuESTEnv {
pub rank: c_int,
pub numRanks: c_int,
pub seeds: *mut c_ulong,
pub numSeeds: c_int,
}
Information about the environment the program is running in.
In practice, this holds info about MPI ranks and helps to hide MPI initialization code
@ingroup type
@author Ania Brown
@author Tyson Jones (seeding)
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.