Struct quest_sys::ComplexArray
source · [−]Expand description
Represents an array of complex numbers grouped into an array of real components and an array of coressponding complex components.
@ingroup type @author Ania Brown
Fields
real: *mut f64imag: *mut f64Trait Implementations
sourceimpl Clone for ComplexArray
impl Clone for ComplexArray
sourcefn clone(&self) -> ComplexArray
fn clone(&self) -> ComplexArray
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ComplexArray
impl Debug for ComplexArray
impl Copy for ComplexArray