Struct quest_sys::DiagonalOp

source ·
#[repr(C)]
pub struct DiagonalOp { pub numQubits: c_int, pub numElemsPerChunk: c_longlong, pub numChunks: c_int, pub chunkId: c_int, pub real: *mut f64, pub imag: *mut f64, pub deviceOperator: ComplexArray, }
Represents a diagonal complex operator on the full Hilbert state of a \p Qureg. The operator need not be unitary nor Hermitian (which would constrain it to real values)

@ingroup type @author Tyson Jones

Fields

numQubits: c_int

! The number of qubits this operator can act on (informing its size)

numElemsPerChunk: c_longlong

! The number of the 2^numQubits amplitudes stored on each distributed node

numChunks: c_int

! The number of nodes between which the elements of this operator are split

chunkId: c_int

! The position of the chunk of the operator held by this process in the full operator

real: *mut f64

! The real values of the 2^numQubits complex elements

imag: *mut f64

! The imaginary values of the 2^numQubits complex elements

deviceOperator: ComplexArray

! A copy of the elements stored persistently on the GPU