#[repr(C)]
pub struct PauliHamil { pub pauliCodes: *mut pauliOpType, pub termCoeffs: *mut f64, pub numSumTerms: c_int, pub numQubits: c_int, }
A Pauli Hamiltonian, expressed as a real-weighted sum of pauli products, and which can hence represent any Hermitian operator.

@ingroup type @author Tyson Jones

Fields

pauliCodes: *mut pauliOpType

! The Pauli operators acting on each qubit, flattened over every operator. ! This is a flat array of length PauliHamil.numSumTerms * PauliHamil.numQubits.

termCoeffs: *mut f64

! The real coefficient of each Pauli product. This is an array of length PauliHamil.numSumTerms;

numSumTerms: c_int

! The number of terms in the weighted sum, or the number of Pauli products.

numQubits: c_int

! The number of qubits informing the Hilbert dimension of the Hamiltonian.